/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

.navbar-spacer {
	flex: 1 1 auto;
}

.navbar {
	z-index: 2;
}

.navbar-brand {
	text-decoration: none;
	color: white;
}

.navbar-container {
	display: flex;
	flex-direction: column;
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
}

.navbar-is-mobile .navbar {
	position: fixed;
	/* Make sure the toolbar will stay on top of the content as it scrolls past. */
	z-index: 2;
}

.navbar-sidenav-container {
	/* When the sidenav is not fixed, stretch the sidenav container to fill the available space. This
			 causes `<mat-sidenav-content>` to act as our scrolling element for desktop layouts. */
	flex: 1;
}

.navbar-is-mobile .navbar-sidenav-container {
	/* When the sidenav is fixed, don't constrain the height of the sidenav container. This allows the
			 `<body>` to be our scrolling element for mobile layouts. */
	flex: 1 0 auto;
}

/*Set sidenav width*/

mat-sidenav {
	min-width: 180px !important;
	border-right: 1px solid #eee;
	box-shadow: 6px 0 6px rgba(0, 0, 0, .1);
	/* background-color:rgb(63, 81, 181); */
}

/* Set height of wrapper to stop content from moving up & down */

.progress-bar-container {
	height: 5px;
}

a.mat-list-item.active {
	background: rgba(0, 0, 0, .04);
}

#push-bottom {
	position: absolute;
	bottom: 0;
}
