/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

table {
	width: 100%;
}

th.mat-sort-header-sorted {
	color: black;
}

mat-card-header {
	display: flex;

	button {
		margin-left: auto;
	}
}

.container {
	margin: 2em;
}

.demo-table {
	width: 100%;
}

button {
	margin: 0.5em 0.5em 0.5em 0;
}

.online-worker {
	color: green;
}

.offline-worker {
	color: darkred;
}

.loading {
	animation: rotation 2s infinite linear;
	filter: brightness(1.5);
}
@keyframes rotation {
	from {
		transform: rotate(0deg);
	}
	to {
		transform: rotate(359deg);
	}
}
